<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=uk
// ** ne pas modifier le fichier **

return [

	// F
	'forum_description' => 'Форуми у SPIP (загальні і редакційні)',
	'forum_slogan' => 'Управління загальними і редакційними форумами у SPIP',
];
